==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/model/PlayerMaidModel.java <==
package com.github.tartaricacid.touhoulittlemaid.client.model;

import com.github.tartaricacid.simplebedrockmodel.client.bedrock.pojo.BedrockModelPOJO;
import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.client.animation.script.ModelRendererWrapper;
import com.github.tartaricacid.touhoulittlemaid.client.model.bedrock.BedrockModel;
import com.github.tartaricacid.touhoulittlemaid.client.resource.CustomPackLoader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.nio.charset.StandardCharsets;
import net.minecraft.class_1308;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3300;

public class PlayerMaidModel extends BedrockModel<class_1308> {
    private static final class_2960 STEVE = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "models/entity/player_maid.json");
    private static final class_2960 ALEX = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "models/entity/player_maid_slim.json");

    public PlayerMaidModel(boolean smallArms) {
        class_3300 manager = class_310.method_1551().method_1478();
        if (smallArms) {
            try (InputStream stream = manager.open(ALEX)) {
                loadNewModel(CustomPackLoader.GSON.fromJson(new InputStreamReader(stream, StandardCharsets.UTF_8), BedrockModelPOJO.class));
            } catch (IOException exception) {
                exception.printStackTrace();
            }
        } else {
            try (InputStream stream = manager.open(STEVE)) {
                loadLegacyModel(CustomPackLoader.GSON.fromJson(new InputStreamReader(stream, StandardCharsets.UTF_8), BedrockModelPOJO.class));
            } catch (IOException exception) {
                exception.printStackTrace();
            }
        }
        this.modelMap.forEach((key, model) -> modelMapWrapper.put(key, new ModelRendererWrapper(model)));
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.4.3-neo1.4.5-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/model/PlayerMaidModel.java <==
package com.github.tartaricacid.touhoulittlemaid.client.model;

import com.github.tartaricacid.simplebedrockmodel.client.bedrock.pojo.BedrockModelPOJO;
import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.client.animation.script.ModelRendererWrapper;
import com.github.tartaricacid.touhoulittlemaid.client.model.bedrock.BedrockModel;
import com.github.tartaricacid.touhoulittlemaid.client.resource.CustomPackLoader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.nio.charset.StandardCharsets;
import net.minecraft.class_1308;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3300;

public class PlayerMaidModel extends BedrockModel<class_1308> {
    private static final class_2960 STEVE = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "models/bedrock/entity/player_maid.json");
    private static final class_2960 ALEX = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "models/bedrock/entity/player_maid_slim.json");

    public PlayerMaidModel(boolean smallArms) {
        class_3300 manager = class_310.method_1551().method_1478();
        if (smallArms) {
            try (InputStream stream = manager.open(ALEX)) {
                loadNewModel(CustomPackLoader.GSON.fromJson(new InputStreamReader(stream, StandardCharsets.UTF_8), BedrockModelPOJO.class));
            } catch (IOException exception) {
                TouhouLittleMaid.LOGGER.error("Failed to load alex player maid model", exception);
            }
        } else {
            try (InputStream stream = manager.open(STEVE)) {
                loadLegacyModel(CustomPackLoader.GSON.fromJson(new InputStreamReader(stream, StandardCharsets.UTF_8), BedrockModelPOJO.class));
            } catch (IOException exception) {
                TouhouLittleMaid.LOGGER.error("Failed to load steve player maid model", exception);
            }
        }
        this.modelMap.forEach((key, model) -> modelMapWrapper.put(key, new ModelRendererWrapper(model)));
    }
}
